==> igniteui-react-charts-16.6.8.tgz: package/ES5/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var ChaikinOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ChaikinOscillatorIndicator, _super);
    function ChaikinOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicator.prototype.get_p5 = function () {
        return new ChaikinOscillatorIndicatorStrategy();
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.get_qi = function () {
        return ChaikinOscillatorIndicator.$;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.qr));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.qd = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.qq));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.qq, a);
        },
        enumerable: true,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.qa = function () {
        return this.longPeriod;
    };
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.qr = StrategyBasedIndicator.qp(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.qq = StrategyBasedIndicator.ql(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
}(StrategyBasedIndicator));
export { ChaikinOscillatorIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var ChaikinOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ChaikinOscillatorIndicator, _super);
    function ChaikinOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicator.prototype.get_qc = function () {
        return new ChaikinOscillatorIndicatorStrategy();
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.get_qp = function () {
        return ChaikinOscillatorIndicator.$;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.qy));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.qk = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.qx));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.qx, a);
        },
        enumerable: true,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.qh = function () {
        return this.longPeriod;
    };
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.qy = StrategyBasedIndicator.qw(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.qx = StrategyBasedIndicator.qs(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
}(StrategyBasedIndicator));
export { ChaikinOscillatorIndicator };
